@@ -22,6 +22,7 @@ from requests import Session, Timeout
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util import Retry
 
+from cord.configs import BaseConfig
 from cord.exceptions import *
 from cord.http.error_utils import check_error_response
 from cord.http.query_methods import QueryMethods
@@ -32,7 +33,7 @@ class Querier:
     """ Querier for DB get/post requests. """
     T = TypeVar('T')
 
-    def __init__(self, config):
+    def __init__(self, config: BaseConfig):
         self._config = config
 
     def basic_getter(self, db_object_type: Type[T], uid=None) -> T:
@@ -52,19 +53,20 @@ class Querier:
         else:
             raise ResourceNotFoundError("Resource not found.")
 
-    def get_multiple(self, object_type: Type[T], uid=None) -> List[T]:
+    def get_multiple(self, object_type: Type[T], uid=None, payload=None) -> List[T]:
         request = self.request(
             QueryMethods.GET,
             object_type,
             uid,
             self._config.read_timeout,
+            payload=payload
         )
         result = self.execute(request)
 
-        if result:
+        if result is not None:
             return [object_type(**item) for item in result]
         else:
-            raise ResourceNotFoundError("Resource not found.")
+            raise ResourceNotFoundError(f"[{object_type}] not found for query with uid=[{uid}] and payload=[{payload}]")
 
     def basic_delete(self, db_object_type: Type[T], uid=None):
         """ Single DB object getter. """
@@ -112,16 +114,10 @@ class Querier:
             raise RequestException("Setting %s with uid %s failed." % (db_object_type, uid))
 
     def request(self, method, db_object_type: Type[T], uid, timeout, payload=None):
-        """ Request object constructor. """
-        return Request(
-            method,
-            db_object_type,
-            uid,
-            self._config.headers,
-            timeout,
-            self._config.connect_timeout,
-            payload,
-        )
+        request = Request(method, db_object_type, uid, timeout, self._config.connect_timeout, payload)
+
+        request.headers = self._config.define_headers(request.data)
+        return request
 
     def execute(self, request):
         """ Execute a request. """
