@@ -31,7 +31,7 @@ class LabelingAlgorithm(base_orm.BaseORM):
 
     DB_FIELDS = OrderedDict([
         ("algorithm_name", str),
-        ("algorithm_parameters", dict),  # algorithm params
+        ("algorithm_parameters", dict),  # Algorithm params
     ])
 
 
@@ -50,3 +50,20 @@ class ObjectInterpolationParams(base_orm.BaseORM):
         ("key_frames", dict),
         ("objects_to_interpolate", list),
     ])
+
+
+class BoundingBoxFittingParams(base_orm.BaseORM):
+    """
+        Labeling algorithm parameters for bounding box fitting algorithm
+
+        ORM:
+
+        labels,
+        video
+
+        """
+
+    DB_FIELDS = OrderedDict([
+        ("labels", dict),
+        ("video", dict),
+    ])
